utils.get_affected_ids_by_grb_change – BRDR - Aligning borders

# utils.get_affected_ids_by_grb_change

    be.grb.utils.get_affected_ids_by_grb_change(
        thematic_geometries,
        *,
        grb_type=GRBType.ADP,
        date_start=date.today(),
        date_end=date.today(),
        one_by_one=False,
        border_distance=0,
        geometry_thematic_union=None,
        crs=DEFAULT_CRS,
    )

Get a list of affected IDs by GRB-changes in a specific timespan

Args: thematic_geometries: dictionary if thematicID & Geometry grb_type: Type of GRB: parcels, buildings,… date_start: start-date to check changes in GRB date_end: end-date to check changes in GRB one_by_one: parameter to choose the methodology to check changes: * True: Every thematic geometry is checked individually (loop) * False: All GRB-parcels intersecting the thematic dictionary are checked at once (Default: False) border_distance: Distance that can be used to only check the ‘border’ of the geometry, so ‘big’ geometries with internal parcel-updates are not affected (Default:0, indicating that the full geometry is checked for GRB-changes) Returns: list of affected IDs